@@ -1,8 +1,10 @@
 import io
 
-import ecl_data_io.types as ecl_io_types
 import numpy as np
+
+import ecl_data_io.types as ecl_types
 from ecl_data_io._unformatted.common import bytes_in_array, group_len, item_size
+from ecl_data_io._unformatted.write import write_array_like
 from ecl_data_io.array_entry import EclArray
 from ecl_data_io.errors import EclParsingError
 
@@ -12,24 +14,6 @@ class UnformattedEclArray(EclArray):
     An array entry in a unformatted ecl file.
     """
 
-    def read_keyword(self):
-        """
-        Read the keyword from the unformatted ecl file.
-        :returns: The keyword as a 8 character string.
-        """
-        if self._keyword is None:
-            self._read()
-        return self._keyword.decode("ascii")
-
-    def read_length(self):
-        """
-        Read the length from the unformatted ecl file.
-        :returns: The length of the array in number of entries.
-        """
-        if self._length is None:
-            self._read()
-        return self._length
-
     def read_array(self):
         """
         Read the array from the unformatted ecl file.
@@ -37,10 +21,11 @@ class UnformattedEclArray(EclArray):
         """
         if self._data_start is None:
             self._read()
-
+        if self._type == b"MESS":
+            return ecl_types.MESS
         self.stream.seek(self._data_start)
-        g_len = group_len(self.type)
-        np_type = ecl_io_types.to_np_type(self._type)
+        g_len = group_len(self._type)
+        np_type = ecl_types.to_np_type(self._type)
         array = np.zeros(shape=(self._length,), dtype=np_type)
         to_read = self._length
         type_len = item_size(self._type)
@@ -62,6 +47,26 @@ class UnformattedEclArray(EclArray):
 
         return array
 
+    def update(self, *, keyword=None, array=None):
+        if keyword is None:
+            keyword = self.read_keyword()
+
+        if array is not ecl_types.MESS:
+            if array is not None:
+                array = np.asarray(array)
+            else:
+                array = self.read_array()
+            if array is not ecl_types.MESS and self.read_length() != array.size:
+                raise ValueError("Cannot update array with different size")
+
+        if self.read_type() != ecl_types.from_np_dtype(array):
+            raise ValueError("Cannot update array with different type")
+
+        self.stream.seek(self.start)
+        write_array_like(self.stream, keyword, array)
+        self._keyword = keyword
+        self._array = array
+
     def _read_record_marker(self, expected_value):
         """
         Read 4 bytes and check that it matches the
@@ -78,7 +83,7 @@ class UnformattedEclArray(EclArray):
         With stream.peek() at the start of the keyword, reads
         it into self._keyword
         """
-        self._keyword = self.stream.read(8)
+        self._keyword = self.stream.read(8).decode("ascii")
         if not self._keyword or len(self._keyword) < 8:
             raise EclParsingError("Reached end-of-file while reading keyword")
 
@@ -121,7 +126,7 @@ class UnformattedEclArray(EclArray):
         self._read_record_marker(16)
         if self._type == b"X231":
             self._read_record_marker(16)
-            self._length *= -(2 ** 31)
+            self._length *= -(2**31)
             previous_keyword = self._keyword
             self._read_keyword()
             if previous_keyword != self._keyword:
@@ -145,7 +150,7 @@ class UnformattedEclArray(EclArray):
                 f"has item length {type_len} which requires 0 number of"
                 f"elements, but found {self._length} amount of elements."
             )
-        bytes_to_skip = bytes_in_array(self._length, self.type)
+        bytes_to_skip = bytes_in_array(self._length, self._type)
 
         self._data_start = self.stream.tell()
         self.stream.seek(bytes_to_skip, io.SEEK_CUR)
